summaryrefslogtreecommitdiff
path: root/include/m_protocols.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/m_protocols.h')
-rw-r--r--include/m_protocols.h16
1 files changed, 9 insertions, 7 deletions
diff --git a/include/m_protocols.h b/include/m_protocols.h
index 67ffd950ff..0897e0e199 100644
--- a/include/m_protocols.h
+++ b/include/m_protocols.h
@@ -281,15 +281,17 @@ typedef struct tagACCOUNT
char* szModuleName; // unique physical account name (matches database module name)
TCHAR* tszAccountName; // user-defined account name
char* szProtoName; // physical protocol name
- int bIsEnabled; // is account enabled?
- int bIsVisible; // is account visible?
- int iOrder; // account order in various menus & lists
- BOOL bOldProto; // old-styled account (one instance per dll)
- PROTO_INTERFACE *ppro; // pointer to the underlying object
+ bool bIsEnabled; // is account enabled?
+ bool bIsVisible; // is account visible?
+ bool bIsVirtual; // is account virtual?
+ bool bOldProto; // old-styled account (one instance per dll)
+ bool bDynDisabled; // dynamic disable flag, is never written to db
+ bool bAccMgrUIChanged;
HWND hwndAccMgrUI;
- BOOL bAccMgrUIChanged;
- BOOL bDynDisabled; // dynamic disable flag, is never written to db
+
+ int iOrder; // account order in various menus & lists
+ PROTO_INTERFACE *ppro; // pointer to the underlying object
}
PROTOACCOUNT;